@@ -12,7 +12,7 @@ use strict;
 use Spreadsheet::WriteExcelXML;
 
 # Create a new workbook and add a worksheet
-my $workbook  = Spreadsheet::WriteExcelXML->new("array_formula.xml");
+my $workbook  = Spreadsheet::WriteExcelXML->new("array_formula.xls");
 
 die "Couldn't create new Excel file: $!.\n" unless defined $workbook;
 
