@@ -15,7 +15,7 @@ use strict;
 use Spreadsheet::WriteExcelXML;
 
 # Create a new workbook and add a worksheet
-my $workbook  = Spreadsheet::WriteExcelXML->new("merge1.xml");
+my $workbook  = Spreadsheet::WriteExcelXML->new("merge1.xls");
 die "Couldn't create new Excel file: $!.\n" unless defined $workbook;
 
 
